declare const CROSSMINT_API_KEY_SIGNER_PUBLICKEY_STAGING = "3hSfN4dWSwgCg1uf2yytBtK6KxK3ySFKasd2h9J2vSK5";
declare const CROSSMINT_API_KEY_SIGNER_PUBLICKEY_PROD = "8erZh8YApGck3iUSUHqATBxqMTM1Ukp9mHmvGgUWHtkK";

declare const APIKeyUsageOriginPrefix: {
    readonly CLIENT: "ck";
    readonly SERVER: "sk";
};
type APIKeyUsageOriginPrefix = (typeof APIKeyUsageOriginPrefix)[keyof typeof APIKeyUsageOriginPrefix];
declare const APIKeyEnvironmentPrefix: {
    readonly DEVELOPMENT: "development";
    readonly STAGING: "staging";
    readonly PRODUCTION: "production";
};
type APIKeyEnvironmentPrefix = (typeof APIKeyEnvironmentPrefix)[keyof typeof APIKeyEnvironmentPrefix];
type APIKeyPrefix = `${APIKeyUsageOriginPrefix}_${APIKeyEnvironmentPrefix}`;
declare const APIKeyUsageOrigin: {
    readonly CLIENT: "client";
    readonly SERVER: "server";
};
type APIKeyUsageOrigin = (typeof APIKeyUsageOrigin)[keyof typeof APIKeyUsageOrigin];

declare function usageOriginToPrefix(usageOrigin: APIKeyUsageOrigin): APIKeyUsageOriginPrefix;
declare function environmentToExpectedPublicKey(environment?: APIKeyEnvironmentPrefix): string | null;

type ValidateAPIKeyPrefixResult = ({
    isValid: true;
} & ValidateAPIKeyPrefixSuccessData) | {
    isValid: false;
    message: string;
};
type ValidateAPIKeyPrefixSuccessData = {
    usageOrigin: APIKeyUsageOrigin;
    environment: APIKeyEnvironmentPrefix;
    prefix: APIKeyPrefix;
};
type ValidateAPIKeyPrefixExpectations = {
    usageOrigin?: APIKeyUsageOrigin;
    environment?: APIKeyEnvironmentPrefix;
};
declare function validateAPIKeyPrefix(apiKey: string, expectations?: ValidateAPIKeyPrefixExpectations): ValidateAPIKeyPrefixResult;

type ValidateAPIKeyResult = ({
    isValid: true;
    projectId: string;
} & ValidateAPIKeyPrefixSuccessData) | {
    isValid: false;
    message: string;
};
declare function validateAPIKey(apiKey: string, expectations?: ValidateAPIKeyPrefixExpectations): ValidateAPIKeyResult;

interface UiConfigColors {
    textPrimary?: string;
    textSecondary?: string;
    accent?: string;
    background?: string;
    backgroundSecondary?: string;
    backgroundTertiary?: string;
    border?: string;
    danger?: string;
    textLink?: string;
}
interface UIConfig {
    colors?: UiConfigColors;
    fontSizeBase?: string;
    spacingUnit?: string;
    borderRadius?: string;
    fontWeightPrimary?: string;
    fontWeightSecondary?: string;
    fonts?: UiConfigFonts;
}
type UiConfigFonts = (CssFontSource | CustomFontSource)[];
interface CssFontSource {
    cssSrc: string;
    family: string;
}
interface CustomFontSource {
    family: string;
    src: string;
    display?: string;
    style?: "normal" | "italic" | "oblique";
    weight?: string;
}

declare const EVM_CHAINS: readonly ["ethereum", "ethereum-sepolia", "polygon", "bsc", "optimism", "arbitrum", "base", "zora", "arbitrumnova", "zkatana"];
declare const BLOCKCHAIN_TEST_NET: readonly ["goerli", "ethereum-sepolia", "mumbai", "zkatana"];
declare const ALL_CHAINS: readonly ["solana", "cardano", "sui", "ethereum", "ethereum-sepolia", "polygon", "bsc", "optimism", "arbitrum", "base", "zora", "arbitrumnova", "zkatana"];
declare const EVM_BLOCKCHAIN_INCLUDING_TESTNET: readonly ["ethereum", "ethereum-sepolia", "polygon", "bsc", "optimism", "arbitrum", "base", "zora", "arbitrumnova", "zkatana", "goerli", "ethereum-sepolia", "mumbai", "zkatana"];
declare const BLOCKCHAIN_INCLUDING_TESTNET: readonly ["solana", "cardano", "sui", "ethereum", "ethereum-sepolia", "polygon", "bsc", "optimism", "arbitrum", "base", "zora", "arbitrumnova", "zkatana", "goerli", "ethereum-sepolia", "mumbai", "zkatana"];
type Blockchain = (typeof ALL_CHAINS)[number];
type EVMBlockchain = (typeof EVM_CHAINS)[number];
type BlockchainTestNet = (typeof BLOCKCHAIN_TEST_NET)[number];
type EVMBlockchainIncludingTestnet = (typeof EVM_BLOCKCHAIN_INCLUDING_TESTNET)[number];
type BlockchainIncludingTestnet = (typeof BLOCKCHAIN_INCLUDING_TESTNET)[number];
interface Wallet {
    chain: string;
    publicKey: string;
}
interface EVMNFT {
    chain: EVMBlockchain;
    contractAddress: string;
    tokenId: string;
}
interface SolanaNFT {
    mintHash: string;
    chain: "solana";
}
interface CardanoNFT {
    chain: "cardano";
    assetId: string;
}
type NFTLocator<T extends Blockchain> = `${T}:${string}${T extends EVMBlockchain ? `:${string}` : ""}`;
type NFT = SolanaNFT | EVMNFT | CardanoNFT;
type NFTOrNFTLocator = NFT | NFTLocator<"solana"> | NFTLocator<"ethereum"> | NFTLocator<"polygon"> | NFTLocator<"bsc"> | NFTLocator<"cardano">;
interface CommonProps {
    uiConfig?: UIConfig;
    environment?: string;
}
interface NFTCollectionViewProps extends CommonProps {
    wallets: Wallet[];
}
interface NFTDetailProps extends CommonProps {
    nft: NFTOrNFTLocator;
}

type UserIdentifierParams = {
    email?: string;
    userId?: string;
    phoneNumber?: string;
};
type UserIdentifier = {
    type: "whiteLabel";
    userId: string;
} | {
    type: "email";
    email: string;
} | {
    type: "phoneNumber";
    phoneNumber: string;
};

export { ALL_CHAINS, APIKeyEnvironmentPrefix, APIKeyPrefix, APIKeyUsageOrigin, APIKeyUsageOriginPrefix, BLOCKCHAIN_INCLUDING_TESTNET, BLOCKCHAIN_TEST_NET, Blockchain, BlockchainIncludingTestnet, BlockchainTestNet, CROSSMINT_API_KEY_SIGNER_PUBLICKEY_PROD, CROSSMINT_API_KEY_SIGNER_PUBLICKEY_STAGING, CardanoNFT, CssFontSource, CustomFontSource, EVMBlockchain, EVMBlockchainIncludingTestnet, EVMNFT, EVM_BLOCKCHAIN_INCLUDING_TESTNET, EVM_CHAINS, NFT, NFTCollectionViewProps, NFTDetailProps, NFTLocator, NFTOrNFTLocator, SolanaNFT, UIConfig, UiConfigColors, UiConfigFonts, UserIdentifier, UserIdentifierParams, ValidateAPIKeyPrefixExpectations, ValidateAPIKeyPrefixResult, ValidateAPIKeyPrefixSuccessData, ValidateAPIKeyResult, Wallet, environmentToExpectedPublicKey, usageOriginToPrefix, validateAPIKey, validateAPIKeyPrefix };
